==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nome do processo</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Linha de comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Hora de início</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Leitura em disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Gravação em disco</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Troca</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não ativado</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Transferir</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura em disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Gravação em disco</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forçar fecho da aplicação</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema negro</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Terminar aplicação</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Terminar esta aplicação poderá causar a perda de dados.
Tem a certeza que pretende continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Modo compacto</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Troca</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não ativado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Transferir</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sem resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Terminar processo</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Terminar este processo poderá causar a perda de dados.
Tem a certeza que pretende continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Retomar processo</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Ver localização do processo</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicações e %3 processos em execução</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Gravação em disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura em disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Transferir</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>O Deepin System Monitor é monitor do sistema poderoso e intuitivo. Este pode monitorizar os processos da CPU, memória, rede, disco e outros estados.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - Serviço de iniciação de processos</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Ambiente de Trabalho</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Proxy polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Lançador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Gestor de Ecrã</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Daemon da sessão</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - Processo de inicialização de sessão</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin File Manager - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Serviço do ecrã de bloqueio</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Window Manager</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Alternador do Deepin Window Manager</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notificação do Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente do Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Menu de serviço do Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Store - Daemon</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Daemon de correspondência de janelas</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Deamon de correspondência de janelas do serviço DBus</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Daemon do sistema de ficheiros do modo utilizador virtual</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Daemon do servidor Fuse do sistema de ficheiros do modo utilizador virtual</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processo auxiliar do cliente da Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gestor de rede</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Serviço PolicyKit DBus</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Daemon do serviço de partilha de ficheiros</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Serviço X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Daemon DBus do método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Daemon do método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Serviço de áudio</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Daemon de impressão</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gestor do Light display</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gestor de serviços do sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Gestor de serviços do sistema - Daemon do gestor de dispositivos</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Daemon do disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Daemon da conta</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Daemon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Daemon de eventos do rato</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Serviço Dconf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Daemon do gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Daemon do bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Daemon de energia</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gestor de dispositivos modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Serviço tray do sistema de impressão</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Sandbox do Navegador Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Daemon do dispositivo de toque Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Troca</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não ativado</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Método de introdução Sogou</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clique na aplicação que deseja terminar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Os meus processos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos os processos</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nome do processo</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Iniciado a</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forçar fecho da aplicação</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema negro</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Terminar aplicação</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Terminar esta aplicação poderá causar perda de dados.Tem a certeza que quer continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não ativado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sem resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Terminar processo</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Terminar este processo poderá causar perda de dados.
Tem a certeza que quer continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Resumir processo</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Ver localização do processo</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicações e %3 processos em execução</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escrita em disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura em disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>O Deepin System Monitor é um intuitivo e potente monitor de sistema. Pode monitorizar os processos em CPU, memória, rede, disco e outros estados.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - Serviço de iniciação de processos</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Ambiente de trabalho</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Proxy polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Lançador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Gestor de ecrã</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Daemon da sessão</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - Processo de inicialização de sessão</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Daemon do Deepin File Manager</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Serviço do ecrã de bloqueio</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Window Manager</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Alternador do Deepin Window Manager</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notificações do Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente do Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Menu de serviço do Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Daemon da Deepin Store</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Daemon de correspondência de janelas</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Deamon de correspondência de janelas do serviço DBus</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Daemon do sistema de ficheiros do modo utilizador virtual</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Daemon do servidor Fuse do sistema de ficheiros do modo utilizador virtual</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processo auxiliar do cliente da Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gestor de rede</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Serviço PolicyKit DBus</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Daemon do serviço de partilha de ficheiros</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Serviço X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Daemon DBus do método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Daemon do método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Serviço de áudio</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Daemon de impressão</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gestor do Light display</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gestor de serviços do sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Gestor de serviços do sistema - Daemon do gestor de dispositivos</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Daemon do disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Daemon da conta</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Daemon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Daemon de eventos do rato</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Serviço Dconf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Daemon do gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Daemon do bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Daemon de energia</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gestor de dispositivos modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Serviço tray do sistema de impressão</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Sandbox do Navegador Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Daemon do dispositivo de toque Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não ativo</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clique na aplicação que deseja terminar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Meus processos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos os processos</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
</context>
</TS>
